import { Type } from "./type";
/**
 * Describes available radial label modes.
 */
export declare enum RadialLabelMode {
    /**
     * Labelling mode is determined automatically.
     */
    Auto = 0,
    /**
     * Labelling mode is defined by the settings of the callout layer.
     */
    Normal = 1,
    /**
     * The value of the item is displayed.
     */
    Value = 2,
    /**
     * The percentage of the whole is displayed, if using a proportional axis, otherwise the value is used as a fallback.
     */
    Percentage = 3,
    /**
     * The value and the percentage are displayed, if using a proportional axis, otherwise the value is used as a fallback.
     */
    ValueAndPercentage = 4,
    /**
     * The label of the category is used as a label.
     */
    Label = 5,
    /**
     * The label of the category and the value are used as the label.
     */
    LabelAndValue = 6,
    /**
     * The label of the category and the percentage are used as the label, if using a proportional axis, otherwise the label and value is used as a fallback.
     */
    LabelAndPercentage = 7,
    /**
     * The label of the category and the value and the percentage are used as the label, if using a proportional axis, otherwise the label and value is used as a fallback.
     */
    LabelAndValueAndPercentage = 8
}
/**
 * @hidden
 */
export declare let RadialLabelMode_$type: Type;
